@@ -3,10 +3,10 @@
 #' Tries to heuristically determine the variable name of \code{x} in the parent frame
 #' with a combination of \code{\link[base]{deparse}} and \code{\link[base]{substitute}}.
 #' Used for checkmate's error messages.
-#' @param x [ANY]\cr
+#' @param x [\code{any}]\cr
 #'   Object.
 #' @return [\code{character(1)}] Variable name.
 #' @export
 vname = function(x) {
-  paste0(deparse(substitute(x, parent.frame(1L)), width.cutoff = 500), collapse = "\n")
+  paste0(deparse(eval.parent(substitute(substitute(x))), width.cutoff = 500L), collapse = "\n")
 }
