@@ -2,6 +2,10 @@
 #include "backports.h"
 
 R_xlen_t attribute_hidden find_missing_logical(SEXP x) {
+#if defined(R_VERSION) && R_VERSION >= R_Version(3, 6, 0)
+    if (LOGICAL_NO_NA(x))
+        return 0;
+#endif
     const R_xlen_t n = xlength(x);
     const int * xp = LOGICAL_RO(x);
     for (R_xlen_t i = 0; i < n; i++) {
@@ -100,34 +104,22 @@ R_xlen_t attribute_hidden find_missing_vector(SEXP x) {
     }
 }
 
-pos2d_t attribute_hidden find_missing_matrix(SEXP x) {
-    pos2d_t pos;
-    R_xlen_t ii = find_missing_vector(x);
-    if (ii > 0) {
-        const R_xlen_t ncol = INTEGER_RO(getAttrib(x, R_DimSymbol))[1];
-        ii--;
-        pos.i = ii % ncol + 1;
-        pos.j = (R_xlen_t)(ii / ncol) + 1;
-    } else {
-        pos.i = pos.j = 0;
-    }
-    return pos;
+R_xlen_t attribute_hidden find_missing_matrix(SEXP x) {
+    return find_missing_vector(x);
 }
 
-pos2d_t attribute_hidden find_missing_frame(SEXP x) {
-    pos2d_t pos = { 0, 0 };
+R_xlen_t attribute_hidden find_missing_frame(SEXP x) {
     const R_xlen_t nc = xlength(x);
     for (R_xlen_t j = 0; j < nc; j++) {
         SEXP xj = VECTOR_ELT(x, j);
         if (TYPEOF(xj) != VECSXP) {
             R_xlen_t i = find_missing_vector(xj);
             if (i > 0) {
-                pos.i = i; pos.j = j;
-                break;
+                return (j * length(xj)) + i;
             }
         }
     }
-    return pos;
+    return 0;
 }
 
 Rboolean any_missing(SEXP x) {
@@ -138,9 +130,8 @@ Rboolean any_missing(SEXP x) {
         case CPLXSXP: return find_missing_complex(x) > 0;
         case STRSXP:  return find_missing_string(x) > 0;
         case NILSXP:  return FALSE;
-        case VECSXP:  if (isFrame(x)) {
-                        pos2d_t pos = find_missing_frame(x);
-                        return pos.i > 0;
+        case VECSXP:  if (isDataFrame(x)) {
+                        return find_missing_frame(x) > 0;
                       } else {
                           return find_missing_list(x) > 0;
                       }
